PyXMake Developer Guide: PyXMake.VTL.app Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.app Namespace Reference

## Functions
| main (BuildID, script=VTL.GetSourceCode(8), source=__pyc_src_path, include=VTL.GetIncludeDirectory(os.path.dirname(__pyc_src_path), 8), dependency=VTL.GetLinkDependency(8), output=os.path.join(__pyc_src_path,"Plugin","JupyterLab","src",".dist"), encryption=True, mode="onefile", scratch=VTL.Scratch, verbosity=2, **kwargs)

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile a stand-alone application using PyInstaller
    Created on 02.05.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          - Requires PyCODAC in PYTHONPATH.

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.app.main | ( |  | BuildID,
|  |  | script = VTL.GetSourceCode(8),
|  |  | source = __pyc_src_path,
|  |  | include = VTL.GetIncludeDirectory(os.path.dirname(__pyc_src_path), 8),
|  |  | dependency = VTL.GetLinkDependency(8),
|  |  | output = os.path.join(__pyc_src_path,"Plugin","JupyterLab","src",".dist"),
|  |  | encryption = True,
|  |  | mode = "onefile",
|  |  | scratch = VTL.Scratch,
|  |  | verbosity = 2,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 44 of file app.py.